BaseChartData class abstract

This class holds all data needed for BaseChartPainter.

In this phase we draw the border, and handle touches in an abstract way.

Implementers

Constructors

BaseChartData({FlBorderData? borderData})
It draws 4 borders around your chart, you can customize it using borderData, touchData defines the touch behavior and responses.

Properties

borderData → FlBorderData
Holds data to drawing border around the chart.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
Used for equality check, see EquatableMixin.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

lerp(BaseChartData a, BaseChartData b, double t) → BaseChartData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited