ShowingTooltipIndicators class

Holds data for showing tooltips over a line

Constructors

ShowingTooltipIndicators(List<LineBarSpot> showingSpots)
LineChart shows some tooltips over each LineChartBarData, and showingSpots determines in which spots this tooltip should be shown.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
Used for equality check, see EquatableMixin.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showingSpots → List<LineBarSpot>
Determines the spots that each tooltip should be shown.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited