maxIncluded property
If true (default), a title for the maximum data value is included independent of the sampling interval
Implementation
final bool maxIncluded;
If true (default), a title for the maximum data value is included independent of the sampling interval
final bool maxIncluded;